Changelog
---------

1.0.0 (December 5th, 2017)
^^^^^^^^^^^^^^^^^^^^^^^^

- Switch to Boto3

0.2.1 (March 5th, 2015)
^^^^^^^^^^^^^^^^^^^^^^^^

- Fix hanging tests.
- Add support for multiple MIME types and regex patterns to MimeType validator.
- Add DenyMimeType validator.

0.2.0 (December 5th, 2014)
^^^^^^^^^^^^^^^^^^^^^^^^

- Replace Flask-Storage dependency with boto.
- Add support for Python 3.

0.1.0 (July 9th, 2014)
^^^^^^^^^^^^^^^^^^^^^^^^

- Initial release.
